@@ -542,7 +542,7 @@ class OpenEVSE:
         else:
             # RAPI commands
             _LOGGER.debug("Setting current via RAPI")
-            command = f"$SC {amps}"
+            command = f"$SC {amps} N"
             response = await self.send_command(command)
             _LOGGER.debug("Set current response: %s", response[1])
 
@@ -834,9 +834,11 @@ class OpenEVSE:
         return float(round(self._status["wattsec"] / 3600, 2))
 
     @property
-    def protocol_version(self) -> str:
+    def protocol_version(self) -> str | None:
         """Return the protocol version."""
         assert self._config is not None
+        if self._config["protocol"] == "-":
+            return None
         return self._config["protocol"]
 
     @property
